@@ -39,12 +39,10 @@ class HealthLogUi:
 				lai=session.query(HealthLog).filter(and_(HealthLog.LongActingInsulinName!=None,HealthLog.LongActingInsulinTaken!=None))
 				lai=orderQuery(lai,HealthLog.DTOE,inverse=True).first()
 				if lai:
-					print("Long Acting Insulin")
+					print(f"Long Acting Insulin : HowLongAgo({datetime.now()-lai.DTOE})")
 					num=0
 					view=[]
-					for x in lai.__table__.columns:
-						if getattr(lai,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(lai,str(x.name)))}{Style.reset}')
+					view.append(f"Name: '{lai.LongActingInsulinName}' Taken: {lai.LongActingInsulinTaken} Unit: {lai.LongActingInsulinUnitName} HLID: {lai.HLID} DTOE:{lai.DTOE}")
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
@@ -53,12 +51,11 @@ class HealthLogUi:
 				sai=session.query(HealthLog).filter(and_(HealthLog.ShortActingInsulinName!=None,HealthLog.ShortActingInsulinTaken!=None))
 				sai=orderQuery(sai,HealthLog.DTOE,inverse=True).first()
 				if sai:
-					print("Short Acting Insulin")
+					print(f"Short Acting Insulin : HowLongAgo({datetime.now()-sai.DTOE})")
 					num=1
 					view=[]
-					for x in sai.__table__.columns:
-						if getattr(sai,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(sai,str(x.name)))}{Style.reset}')
+					view.append(f"Name: '{sai.ShortActingInsulinName}' Taken: {sai.ShortActingInsulinTaken} Unit: {sai.ShortActingInsulinUnitName} HLID: {sai.HLID} DTOE:{sai.DTOE}")
+
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
@@ -67,12 +64,12 @@ class HealthLogUi:
 				last_carb=session.query(HealthLog).filter(and_(HealthLog.CarboHydrateIntake!=None,HealthLog.EntryName!=None))
 				last_carb=orderQuery(last_carb,HealthLog.DTOE,inverse=True).first()
 				if last_carb:
-					Print("CarboHydrateIntake")
+					print(f"CarboHydrateIntake : HowLongAgo({datetime.now()-last_carb.DTOE})")
 					num=2					
 					view=[]
 					for x in last_carb.__table__.columns:
 						if getattr(last_carb,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(last_carb,str(x.name)))}{Style.reset}')
+							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(i,str(x.name)))}{Style.reset}')
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
@@ -81,12 +78,10 @@ class HealthLogUi:
 				drug=session.query(HealthLog).filter(HealthLog.DrugQtyConsumed!=None)
 				drug=orderQuery(drug,HealthLog.DTOE,inverse=True).first()
 				if drug:
-					print("Last Drug Dose Taken")
+					print(f"Last Drug Dose Taken : HowLongAgo({datetime.now()-drug.DTOE})")
 					num=3
 					view=[]
-					for x in drug.__table__.columns:
-						if getattr(drug,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(drug,str(x.name)))}{Style.reset}')
+					view.append(f"Name:{drug.EntryName} Barcode:{drug.EntryBarcode} Drug Name: '{drug.DrugConsumed}' Taken: {lai.DrugQtyConsumed} Unit: {drug.DrugQtyConsumedUnitName} HLID: {lai.HLID} DTOE:{lai.DTOE}")
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
@@ -96,54 +91,48 @@ class HealthLogUi:
 				glucose=session.query(HealthLog).filter(and_(HealthLog.BloodSugar!=None,))
 				glucose=orderQuery(glucose,HealthLog.DTOE,inverse=True).first()
 				if glucose:
-					print("Blood Sugar")
+					print(f"Blood Sugar : HowLongAgo({datetime.now()-glucose.DTOE})")
 					num=0
 					view=[]
-					for x in glucose.__table__.columns:
-						if getattr(glucose,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(glucose,str(x.name)))}{Style.reset}')
+					view.append(f"Blood Sugar/Glucose No. : {glucose.BloodSugar} Unit:{glucose.BloodSugarUnitName} HLID: {glucose.HLID} DTOE: {glucose.DTOE}")
+
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
 					status+=1
 
-				height=session.query(HealthLog).filter(and_(HealthLog.BloodSugar!=None,))
+				height=session.query(HealthLog).filter(and_(HealthLog.Height!=None,))
 				height=orderQuery(height,HealthLog.DTOE,inverse=True).first()
 				if height:
-					print("Height")
+					print(f"Height : HowLongAgo({datetime.now()-height.DTOE})")
 					num=0
 					view=[]
-					for x in height.__table__.columns:
-						if getattr(height,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(height,str(x.name)))}{Style.reset}')
+					view.append(f"Height : {height.Height} Unit:{height.HeightUnitName} HLID: {height.HLID} DTOE: {height.DTOE}")
+
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
 					status+=1
 
-				weight=session.query(HealthLog).filter(and_(HealthLog.BloodSugar!=None,))
+				weight=session.query(HealthLog).filter(and_(HealthLog.Weight!=None,))
 				weight=orderQuery(weight,HealthLog.DTOE,inverse=True).first()
 				if weight:
-					print("Weight")
+					print(f"Weight : HowLongAgo({datetime.now()-weight.DTOE})")
 					num=0
 					view=[]
-					for x in weight.__table__.columns:
-						if getattr(weight,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(weight,str(x.name)))}{Style.reset}')
+					view.append(f"Weight : {weight.Weight} Unit:{weight.WeightUnitName} HLID: {weight.HLID} DTOE: {weight.DTOE}")
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
 					status+=1
 
-				heartRate=session.query(HealthLog).filter(and_(HealthLog.BloodSugar!=None,))
+				heartRate=session.query(HealthLog).filter(and_(HealthLog.HeartRate!=None,))
 				heartRate=orderQuery(heartRate,HealthLog.DTOE,inverse=True).first()
 				if heartRate:
-					print("Heart Rate")
+					print(f"Heart Rate : HowLongAgo({datetime.now()-heartRate.DTOE})")
 					num=0
 					view=[]
-					for x in heartRate.__table__.columns:
-						if getattr(heartRate,str(x.name)) not in [None]:
-							view.append(f'{Fore.green_3b}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={Fore.sea_green_2}{str(getattr(heartRate,str(x.name)))}{Style.reset}')
+					view.append(f"HeartRate : {heartRate.HeartRate} Unit:{heartRate.HeartRateUnitName} HLID: {heartRate.HLID} DTOE: {heartRate.DTOE}")
 					msg=f"{'|'.join(view)}"
 					print(std_colorize(msg,num,ct))
 				else:
